# PyQRP: A Simple QRP File interpreter in Python

## Description

PyQRP is a simple automation program that reads data from XL(X)S files and enters them into data fields into difficult to automate gui programs. 

## Install

### Linux

#### From PIP
```
pip3 install pyqrp
```

#### From Source
```
git clone https://github.com/drpresq/pyqrp.git
pip3 install ./pyqrp
```

### Windows

#### From PIP
```
py -m pip install pyqrp
```

#### From Source
```
git clone https://github.com/drpresq/pyqrp.git
py -m pip install ./pyqrp
```


## Usage

### Linux
```
pyqrp
```

### Windows
```
py -m pyqrp
```

